You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@sling.apache.org by ro...@apache.org on 2016/11/16 14:25:07 UTC

svn commit: r1769989 - /sling/trunk/tooling/jenkins/create_jobs.groovy

Author: rombert
Date: Wed Nov 16 14:25:07 2016
New Revision: 1769989

URL: http://svn.apache.org/viewvc?rev=1769989&view=rev
Log:
SLING-6290 - Add a 'rebuildDaily' property for Jenkins jobs

Jobs with the 'rebuildDaily' property set to true will be built once per
day, regardless of being built based on changes from SVN.

Modified:
    sling/trunk/tooling/jenkins/create_jobs.groovy

Modified: sling/trunk/tooling/jenkins/create_jobs.groovy
URL: http://svn.apache.org/viewvc/sling/trunk/tooling/jenkins/create_jobs.groovy?rev=1769989&r1=1769988&r2=1769989&view=diff
==============================================================================
--- sling/trunk/tooling/jenkins/create_jobs.groovy (original)
+++ sling/trunk/tooling/jenkins/create_jobs.groovy Wed Nov 16 14:25:07 2016
@@ -6,7 +6,7 @@ def svnBase = "https://svn.apache.org/re
 //   - downstream (optional): list of downstream projects
 //   - archive (optional): list of archive patterns
 //   - extraGoalsParams (optional): additional string for the Maven goals to execute
 //   - rebuildNightly (optional): boolean, when enabled configures the build to run once every
 //                                24 hours,even if no changes are found in source control
 def modules = [
     [
@@ -253,7 +253,7 @@ def modules = [
     ],
     [
         location: 'bundles/jcr/oak-server',
-        rebuildNightly: true
+        rebuildDaily : true
     ],
     [
         location: 'bundles/jcr/registration'
@@ -886,7 +886,7 @@ for more details</p>''')
             triggers {
                 snapshotDependencies(true)
                 scm('H/15 * * * *')
-                if ( module.rebuildNightly ) {
+                if ( module.rebuildDaily ) {
                     cron('@daily')
                 }
             }
@@ -6,7 +6,7 @@ def svnBase = "https://svn.apache.org/re
 //   - archive (optional): list of archive patterns
 //   - extraGoalsParams (optional): additional string for the Maven goals to execute
-//   - rebuildNightly (optional): boolean, when enabled configures the build to run once every
+//   - rebuildDaily (optional): boolean, when enabled configures the build to run once every
 //                                24 hours,even if no changes are found in source control
 def modules = [